/**
 * @file Environment.h
 *
 * Aspera, Inc.
 */

#ifndef __ENVIRONMENT_H__
#define __ENVIRONMENT_H__

namespace Aspera{
namespace FaspManager{

/// This class contains configuration options for the fasp Manager.
class Environment {
    private:
        static char const* m_fasp2_ascp_path_discovered;
        static char const* m_fasp2_ascp_path_provided;
        static char const* m_port_file_path;
        static u_int16_t m_requested_server_port;

        static void logSettings();
    ~Environment();

    public:

        /// Gets the path to the FASP2 ascp binary.
        /// 
        /// \return the path to the FASP2 ascp binary. If path was not set, return
        ///         the system-specific default.
        static const char* GetFasp2AscpPath();

         /// Gets the path to the file containing the fasp management port.
         /// 
         /// \return the path to the management port file
        static const char* GetPortFilePath();

         /// Sets the path to the FASP2 ascp binary.
         /// 
         /// \param path path to the FASP2 ascp binary
        static void SetFasp2AscpPath(const char* path);
        
        /// Set the management port to be used by Fasp Manager.
        /// Fasp Manager will automatically pick an available port if you do not
        /// set one. If you do set this port make sure that the port number you
        /// specify is actually available. 0 indicates auto select a port.
        /// \param port the port number
        static void SetManagementPort(u_int16_t port);

        /// Get the management port used by Fasp Manager.
        /// 0 indicates an automatically selected port
        /// \return the port number
        static u_int16_t GetManagementPort();
};

}
}
#endif  /* __ENVIRONMENT_H__ */
